# Awesome-Avalonia

[Avalonia](https://github.com/AvaloniaUI/Avalonia) is a cross-platform XAML Framework for the .NET ecosystem.

[<img src="https://avatars2.githubusercontent.com/u/14075148?s=200&v=4" align="right" width="100">](https://avaloniaui.net/)

A curated list of **Awesome** Avalonia libraries and resources.

Contributions are always welcome! Please take a look at the [Contribution Guidelines](https://github.com/AvaloniaCommunity/awesome-avalonia/blob/master/CONTRIBUTING.md) page first.

## Content

- [Awesome-Avalonia ](#awesome-avalonia-)
  - [Content](#content)
  - [General](#general)
  - [Samples and Projects](#samples-and-projects)
    - [Audio and Music](#audio-and-music)
    - [Communication](#communication)
    - [Documents](#documents)
    - [Data Transfer](#data-transfer)
    - [Finance](#finance)
    - [Gaming](#gaming)
    - [Graphics](#graphics)
    - [Productivity](#productivity)
    - [Software Development](#software-development)
    - [Other](#other)
  - [Tutorials](#tutorials)
  - [Libraries \& Extensions](#libraries--extensions)
    - [Generic](#generic)
    - [Localization / Translation / i18n](#localization--translation--i18n)
    - [Theme \& Icons](#theme--icons)
    - [MVVM \& MVP \& MVU](#mvvm--mvp--mvu)
    - [Charts \& Plots \& Diagrams](#charts--plots--diagrams)
    - [Controls](#controls)
      - [Docking Layout](#docking-layout)
      - [Document Viewers](#document-viewers)
      - [Media Players](#media-players)
      - [UI Libraries](#ui-libraries)
    - [Games and Game engines](#games-and-game-engines)
    - [Web Browsers](#web-browsers)
  - [Videos](#videos)
  - [Articles](#articles)
  - [Podcasts](#podcasts)
  - [Presentations slides](#presentations-slides)
  - [Tooling](#tooling)
  - [Books](#books)
  - [E-Books](#e-books)
  - [Courses](#courses)
  - [Community](#community)
  - [Other Languages](#other-languages)

## General

- [Avalonia](https://github.com/AvaloniaUI/Avalonia) - Avalonia source code.
- [Avalonia Dotnet Template](https://github.com/AvaloniaUI/avalonia-dotnet-templates) - Avalonia Templates for `dotnet new`.
- [AvaloniaVS](https://github.com/AvaloniaUI/AvaloniaVS) - Visual Studio Extension for Avalonia.

## Samples and Projects

### Audio and Music

- [432hz Batch Converter](https://github.com/mysteryx93/HanumanInstituteApps/wiki/432hz-Batch-Converter) - Converts and re-encodes music to 432hz.
- [432hz Player](https://github.com/mysteryx93/HanumanInstituteApps/wiki/432hz-Player) - Plays music in 432hz.
- [Amplitude Soundboard](https://github.com/dan0v/AmplitudeSoundboard) - A sleek, cross-platform soundboard, available for Windows, Linux, and macOS.
- [Apollo Studio](https://github.com/mat1jaczyyy/apollo-studio) - Apollo Studio is a standalone editor and live playback engine for RGB Launchpad light effects.
- [OpenPhonos](https://github.com/amp64/openphonos) - A cross-platform Sonos app built with Avalonia.
- [OpenUTAU](https://github.com/stakira/OpenUtau) - A cross-platform singing synthesis platform.
- [Powerliminals Player](https://github.com/mysteryx93/HanumanInstituteApps/wiki/Powerliminals-Player) - Plays multiple audios simultaneously at varying speeds.
- [XmlyDownloader](https://github.com/zxyao145/XmlyDownloader) - Free audio downloader for ximalaya.com based on Avalonia.
- [xquartz](https://gitlab.com/galahadd/xquartz) - Cross-platform, modern, minimalistic, intuitive, simple music player.
- [Xune](https://github.com/VitalElement/Xune) - A cross-platform resurrection of Zune Desktop Music player using AvaloniaUI.

### Communication

- [Egram](https://github.com/egramtel/egram.tel) - Egram is an unofficial cross-platform Telegram client written in C#, .NET Core, ReactiveUI, and Avalonia.
- [GroupMe Desktop Client](https://github.com/alexdillon/GroupMeClientAvalonia) - GroupMe Desktop Client Avalonia is an open-source, cross-platform, modular client for GroupMe messaging.
- [Laney](https://github.com/Elorucov/Laney-Avalonia) - An unofficial cross-platform client for VK Messenger written in C#, .NET and Avalonia.
- [Loon](https://github.com/mike-ward/Loon) - Loon is a cross-platform desktop twitter client. It's minimal design mimics gadget style applications.
- [SkillChat](https://github.com/SkillChat/SkillChat) - A cross-platform open-source messenger with real-time chat, sending files, receiving notifications, and the ability to deploy on a private server.

### Documents

- [AHpx.RG](https://github.com/SinoAHpx/AHpx.RG) - Cross-platform readme generator based on xml summary documentation.
- [MangaReader](https://github.com/MonkAlex/MangaReader) - Help to download updates from online manga readers.
- [ModularDoc](https://github.com/hailstorm75/ModularDoc) - Modular documentation generator for .NET libraries. Currently supporting Markdown only for GitHub, GitLab, and Bitbucket.

### Data Transfer

- [Camelotia](https://github.com/reactiveui/Camelotia) - Cross-platform demo file manager for cloud storage.
- [Jaya](https://github.com/waliarubal/Jaya) - Cross-platform file explorer application for Windows, Linux, and macOS operating systems.
- [Purple Explorer](https://github.com/telstrapurple/PurpleExplorer) - A cross-platform desktop application to manage messages in Azure service bus and queue.

### Finance

- [Nethereum UI](https://github.com/Nethereum/Nethereum.UI.Desktop) - Simple wallet cross-platform using Avalonia UI.
- [WalletWasabi](https://github.com/WalletWasabi/WalletWasabi) - Open-source, non-custodial, privacy focused Bitcoin wallet for Windows, Linux, and macOS. Built-in Tor, CoinJoin, and coin control features.

### Gaming

- [BuildLauncher](https://github.com/fgsfds/BuildLauncher) - Launcher and mods downloader for Build Engine games.
- [ColorMC](https://github.com/Coloryr/ColorMC) - A Minecraft Launcher.
- [MzingaViewer](https://github.com/jonthysell/Mzinga) - Cross-platform UI for playing the board game Hive against compatible AIs.
- [RoadCaptain](https://github.com/sandermvanvliet/RoadCaptain) - Build and run custom routes in Zwift the virtual cycling world.
- [Steam Superheater](https://github.com/fgsfds/Steam-Superheater) - Fixes downloader for Steam games.
- [VRCFaceTracking.Avalonia](https://github.com/dfgHiatus/VRCFaceTracking.Avalonia) - A cross-platform Avalonia re-make of [VRCFaceTracking](https://github.com/benaclejames/VRCFaceTracking).

### Graphics

- [Beutl](https://github.com/b-editor/beutl) - Cross-platform video editing (compositing) software.
- [Core2D](https://github.com/wieslawsoltes/Core2D) - A multi-platform data driven 2D diagram editor.
- [Lacmus](https://github.com/lacmus-foundation/lacmus-app) - The program for searching through photos from the air of lost people in the forest using Retina Net neural network.
- [PicView](https://github.com/Ruben2776/PicView) - Fast, free and customizable image viewer for Windows 10 and 11. 
- [PixelViewer](https://github.com/carina-studio/PixelViewer) - Cross-platform image viewer which supports reading raw Luminance/YUV/RGB/ARGB pixels data from file and rendering it.
- [SpiroNet](https://github.com/wieslawsoltes/SpiroNet) - The .NET C# port of libspiro - conversion between spiro control points and bezier's.
- [TreeViewer](https://github.com/arklumpus/TreeViewer) - Cross-platform software to draw phylogenetic trees.
- [Xamlade](https://github.com/ComradeAkei/Xamlade) - Visual Avalonia UI XAML editor.

### Productivity

- [Betakads](https://github.com/ZadokJoshua/betakads-avalonia-app) - An AI-powered flashcards generator.
- [iTimeSlot](https://github.com/hoyho/iTimeSlot) - A cross-platform and freestyle time management app for you to focus on completing tasks.
- [Sapphire Notes](https://github.com/davidtimovski/sapphire-notes) - A cross-platform desktop application for managing notes.
- [Team Sketch](https://github.com/davidtimovski/team-sketch) - A cross-platform desktop application for collaborative drawing.
- [TwincatToolbox](https://github.com/randolfly/TwincatToolbox) - A toolbox for developing TwinCAT3 programs which helps user to log and plot the specified symbols with predefined frequency.

### Software Development

- [Asv.Drones](https://github.com/asv-soft/asv-drones) - Open source user-friendly software solution designed to provide remote control and monitoring of drones, payloads, and RTK base stations.
- [AvaloniaILSpy](https://github.com/icsharpcode/AvaloniaILSpy) - Avalonia-based .NET Decompiler (port of ILSpy).
- [AvalonStudio](https://github.com/VitalElement/AvalonStudio) - Cross-platform IDE and Shell.
- [BlitzSearch](http://github.com/natestah/blitzSearch) - Windows, Find-in-Files Tool, an improved Find-in-files Experience for any IDE.
- [DAGE](https://github.com/KvanTTT/DAGE) - DAGE is an Desktop Antlr grammar editor.
- [DevTools for Avalonia](https://www.devtools.nlnet.net) - A third-party interface debugging functionality for Avalonia, providing user-friendly and rich debugging features.
- [FVim](https://github.com/yatli/fvim) - Cross-platform Neovim front-end UI, built with F# + Avalonia.
- [Git-It-GUI](https://github.com/reignstudios/Git-It-GUI) - A Git GUI client designed to be simple with game studio collaboration in mind.
- [JSON Formatter](https://github.com/davidtimovski/json-formatter) - A cross-platform desktop application for formatting JSON strings.
- [Kangaroo IP Scanner](https://github.com/ewilliams0305/kangaroo) - Cross-platform IP scanner application.
- [MatoEditor](https://github.com/CoolCoolTomato/MatoEditor) - A beautiful markdown editor.
- [Modern VICE PDB Monitor](https://github.com/MihaMarkic/modern-vice-pdb-monitor) - Provides a cross-platform debugging environment for VICE emulator. Uses AvaloniaEdit as well.
- [Parquet Floor](https://github.com/aloneguid/parquet-dotnet) - Floor is a reference implementation of the desktop application to view Apache Parquet files.
- [Pororoca](https://github.com/alexandrehtrb/Pororoca) - A HTTP testing tool with support for HTTP/2 and HTTP/3. Alternative to Postman.
- [PowerShell GraphicalTools](https://github.com/PowerShell/GraphicalTools) - A module that mixes PowerShell and GUIs!
- [Radish](https://github.com/x2bool/radish) - Cross-platform desktop client designed exclusively for Redis.
- [RestApia Client](https://www.restapia.app/pages/features/code-driven) - Flex your coding skills while building API requests, and enjoy full flexibility without form-based hassles
- [RoslynPad](https://github.com/aelij/RoslynPad) - A cross-platform C# editor based on Roslyn and AvalonEdit.
- [SourceGit](https://github.com/sourcegit-scm/sourcegit) - A cross-platform Git desktop client.
- [Syndiesis](https://github.com/Rekkonnect/Syndiesis) - A syntax (and more) visualizer for C# code powered by Roslyn.
- [ULogViewer](https://github.com/carina-studio/ULogViewer) - Cross-platform universal log viewer which supports customizable logs reading/parsing/displaying.
- [UVtools](https://github.com/sn4k3/UVtools) - A cross-platform MSLA/DLP, file analysis, calibration, repair, conversion, manipulation, image processing, stacked layers, openCV.

### Other
- [Komiic](https://github.com/afunc233/Komiic) - A cross-platform client for [Komiic.com](https://komiic.com)
- [KubeUI](https://github.com/IvanJosipovic/KubeUI) - Kubernetes User Interface.
- [Lemon.ShadowFiend](https://github.com/NeverMorewd/Lemon.ShadowFiend) - A Windows Rdp client.
- [Let It Snow!](https://github.com/ptupitsyn/let-it-snow) - .NET Core Avalonia UI Snow Demo.
- [NP.Avalonia.Demos](https://github.com/npolyak/NP.Avalonia.Demos) - Demos of Avalonia's features.
- [Prism Outlookish](https://github.com/DamianSuess/Learn.PrismAvaloniaOutlookish) - Learn Prism.Avalonia with this boilerplate for Regions, Modules, Dialog Service, Notification Service, and more.
- [Unlimotion](https://github.com/Kibnet/Unlimotion) - A cross-platform open-source task scheduler with unlimited nesting level.
- [xDelta3 Cross GUI](https://github.com/dan0v/xdelta3-cross-gui) - A cross-platform GUI for creating patches using xDelta3 on Windows, Linux, and macOS.
- [YouTube Video Uploader](https://github.com/schoolgunslinger/YouTube-Video-Uploader-Avalonia) - Converted from WPF to Avalonia cross-platform tool for uploading videos to YouTube.
- [YoutubeDownloader](https://github.com/legend2ks/YoutubeDownloader) - Open-source YouTube video downloader.

## Tutorials

- [AngelMunoz - AvaFunc](https://dev.to/tunaxor/desktop-apps-with-avalonia-and-fsharp-4n21) - Desktop Apps with Avalonia and FSharp.
- [Avalonia.Samples](https://github.com/AvaloniaUI/Avalonia.Samples) - A collection of minimal samples and tutorials.
- [Avalonia for WPF Developers](https://docs.avaloniaui.net/docs/next/get-started/wpf/) - Quick start for WPF developers.
- [AvaloniaUI Tutorial](https://docs.avaloniaui.net/docs/next/tutorials) - Official AvaloniaUI tutorial.
- [Build Modern Cross-Platform Apps with .NET](https://github.com/mysteryx93/Modern.Net-Tutorial) - Covers all areas of development: Avalonia, Dependency Injection, MVVM, Unit Testing, Reactive, and Deployment.
- [First App Tutorial](https://habr.com/en/articles/470101/) - Quick tutorial for creating your first app.
- [Full App for Beginners](https://medium.com/@f98f96/avaloniaui-for-beginners-lets-go-624683372c06) - Tutorial for creating a calculator. Create a full app with design, MVVM, and styling.
- [macOS Sparkle Updates](https://github.com/Deadpikle/macOS.SparkleUpdater.Avalonia) - Example on using the popular [Sparkle](https://github.com/sparkle-project/Sparkle) library in Avalonia.
- [Quickstart](https://docs.avaloniaui.net/docs/getting-started/) - Info for quick start with Avalonia UI.
- [Saving Routing State with ReactiveUI and Avalonia](https://habr.com/en/articles/462307/) - For better UX, your app should be capable of saving state to the disk when the app is suspending and of restoring state when the app is resuming.
- [Styles in Avalonia](https://habr.com/en/post/471342/) - Quick start for styling Avalonia.
- [SuperJMN - IoT LedBar](https://github.com/SuperJMN/Avalonia-IoT-LedBar) - AvaloniaUI IoT LED Bar sample.
- [Wilderness Labs, Meadow Foundation](https://www.hackster.io/wilderness-labs/run-meadow-within-an-avalonia-application-68371e) - Learn how to get atmospheric data from a BME688 using Meadow Foundation and display its readings on an Avalonia application.

## Libraries & Extensions

### Generic

- [AsyncImageLoader.Avalonia](https://github.com/AvaloniaUtils/AsyncImageLoader.Avalonia) - Provides asynchronous bitmap loading from web for Avalonia Image control and more.
- [Avalonia.Xaml.Behaviors](https://github.com/AvaloniaUI/Avalonia.Xaml.Behaviors) - Avalonia XAML Behaviors is an easy-to-use means of adding common and reusable interactivity to your Avalonia applications with minimal code.
- [AvaloniaInside.Shell](https://github.com/AvaloniaInside/Shell) - Reduces the complexity of mobile/desktop application development by providing the fundamental features that most applications require such as Shell, Navigation, and Side Menu.
- [Jc.AdMob.Avalonia](https://github.com/jcsawyer/Jc.AdMob.Avalonia) - Library to bring AdMob advertisements to Avalonia mobile projects.
- [Lemon.Hosting.Avaloniaui](https://github.com/NeverMorewd/Hosting.Avaloniaui) - A lightweight module navigation framework built on top of the Microsoft Dependency Injection (MSDI) for AvaloniaUI.
- [Lemon.ModuleNavigation](https://github.com/NeverMorewd/Lemon.ModuleNavigation) - .NET Generic Host support for Avaloniaui app.
- [Nlnet.Avalonia.Css](https://github.com/liwuqingxin/Avalonia.Css) - A library for Avalonia to write styles like CSS.
- [Nukepayload2.SourceGenerators.AvaloniaUI](https://github.com/Nukepayload2/Nukepayload2.SourceGenerators.AvaloniaUI) - Visual Basic source generator for typed Avalonia `x:Name` References.
- [ShowMeTheXaml.Avalonia](https://github.com/AvaloniaUtils/ShowMeTheXaml.Avalonia) - A control that makes it easier to display the corresponding XAML at runtime.
- [Verify.Avalonia](https://github.com/VerifyTests/Verify.Avalonia) - Extends Verify to allow verification of Avalonia UIs using headless testing.

### Localization / Translation / i18n
- [Echoes](https://github.com/Voyonic-Systems/Echoes) - Simple, type-safe translations library.

### Theme & Icons

- [Aero Theme](https://github.com/Splitwirez/avalonia-aero-theme) - Windows Aero Theme for Avalonia.
- [AntDesign.Avalonia](https://github.com/MicroSugarDeveloperOrg/AntDesign.Avalonia) - Avalonia Theme inspired by Ant Design.
- [CherylUI](https://github.com/kikipoulet/CherylUI) - Avalonia UI Library for Mobile Applications.
- [Classic.Avalonia](https://github.com/BAndysc/Classic.Avalonia) - Classic Windows 9x-like theme and controls for Avalonia.
- [Devolutions Avalonia-Extensions](https://github.com/Devolutions/avalonia-extensions) - Avalonia Themes for a MacOS or DevExpress look.
- [HeroIcons.Avalonia](https://github.com/russkyc/heroicons-avalonia) - Hand crafted icons from [Heroicons](https://heroicons.com) made available to AvaloniaUI.
- [Huskui.Avalonia](https://github.com/d3ara1n/Huskui.Avalonia) - A modern, elegant UI component library inspired by [ParkUI](https://park-ui.com/) and using the [Radix Colors](https://www.radix-ui.com/colors) palette.
- [Icons.Avalonia](https://github.com/Projektanker/Icons.Avalonia) - A library to easily display icons in an Avalonia App.
- [Lucide.Avalonia](https://github.com/dme-compunet/Lucide.Avalonia) - Implementation of the Lucide icon library for AvaloniaUI.
- [LucideAvaloniaUI](https://github.com/MarwanFr/LucideAvaloniaUI) - A library for AvaloniaUI that integrates Lucide icons into your Avalonia applications.
- [Magic.Icon](https://github.com/liwuqingxin/Magic.Icon) - An icon class generator for iconfont in avalonia and wpf.
- [Material Design](https://github.com/AvaloniaCommunity/Material.Avalonia) - Collection of styles to help you customize your Avalonia application theme with Material Design.
- [Material.Icons.Avalonia](https://github.com/AvaloniaUtils/Material.Icons.Avalonia) - Lightweight library for easily display 6000+ icons from [MaterialDesignIcons](https://pictogrammers.com/library/mdi/?welcome)
- [Neumorphism.Avalonia](https://github.com/flarive/Neumorphism.Avalonia) - Easy to use and customizable Neumorphism Design implementation for Avalonia.
- [Romzetron.Avalonia](https://github.com/Romzetron/Romzetron.Avalonia) - Avalonia Theme that supports light/dark modes and a variety of color themes.
- [Semi.Avalonia](https://github.com/irihitech/Semi.Avalonia) - Avalonia Theme inspired by Semi Design.
- [ShadUI](https://github.com/accntech/shad-ui) - A modern, beautiful, and intuitive UI library inspired by [shadcn/ui](https://ui.shadcn.com/) and [Suki UI Library](https://kikipoulet.github.io/SukiUI/).
- [SukiUI](https://github.com/kikipoulet/SukiUI) - Avalonia UI Library with a flat design approach.

### MVVM & MVP & MVU

- [Epoxy](https://github.com/kekyo/Epoxy) - Easy, simplicity, and minimalism multi-platform MVVM library.
- [FuncUI](https://github.com/AvaloniaCommunity/Avalonia.FuncUI) - Develop cross-platform MVU GUI Applications using F# and Avalonia (with a view DSL).
- [HanumanInstitute.MvvmDialogs.Avalonia](https://github.com/mysteryx93/HanumanInstitute.MvvmDialogs/) - Simplifies opening dialogs from a view model with MVVM.
- [Markup Declarative](https://github.com/AvaloniaUI/Avalonia.Markup.Declarative) - Provides helpers for declarative UI and MVU Pattern in C# for Avalonia UI.
- [NP.Avalonia.Gidon](https://github.com/npolyak/NP.Avalonia.Gidon) - IoC MVVM framework for Avalonia UI.
- [Prism](https://github.com/AvaloniaCommunity/Prism.Avalonia) - Prism framework support for Avalonia UI.
- [ReactiveElmish.Avalonia](https://github.com/JordanMarr/ReactiveElmish.Avalonia) - MVU applications using F# and Avalonia (with XAML views).
- [ReactiveHistory](https://github.com/wieslawsoltes/ReactiveHistory) - Reactive undo/redo framework for .NET.
- [ReactiveMvvm](https://github.com/reactiveui/ReactiveMvvm) - Cross-platform ReactiveUI & PropertyChanged.Fody demo app.
- [ReactiveValidation](https://github.com/Karnah/ReactiveValidation) - Validating properties with messages on UI using fluent-style rules.
- [Stylet.Avalonia](https://github.com/sealoyal2018/stylet.avalonia) - A very lightweight but powerful ViewModel-First MVVM framework for Avalonia, inspired by Caliburn.Micro.

### Charts & Plots & Diagrams

- [GoDiagram](https://github.com/NorthwoodsSoftware/GoDiagram) - A .NET library for rapidly building interactive diagrams.
- [LiveCharts2](https://github.com/beto-rodriguez/LiveCharts2) - Simple, flexible, interactive & powerful charts, maps and gauges for .NET.
- [Microcharts](https://github.com/AvaloniaCommunity/Avalonia.Microcharts) - A simple Avalonia only port of the Microcharts library.
- [OxyPlot](https://github.com/oxyplot/oxyplot-avalonia) - A cross-platform plotting library for .NET.
- [ScottPlot](https://github.com/ScottPlot/ScottPlot) - Interactive Plotting Library for .NET.
- [StockPlot](https://github.com/BizUnity/StockPlot) - A Stock Markets Technical Analysis library for AvaloniaUI, based on ScottPlot, supporting live data stream.
- [TeeChart](https://github.com/Steema/TeeChart-Avalonia-Samples) - Versatile native .NET Charting, Map, and Gauge control.

### Controls

#### Docking Layout

- [NP.Avalonia.Unidock](https://github.com/npolyak/NP.Avalonia.Unidock) - Simple VS2022-like window and view docking.
- [UniDock](https://github.com/npolyak/NP.Avalonia.UniDock) - A docking layout system.

#### Document Viewers

- [Markdown.Avalonia](https://github.com/whistyun/Markdown.Avalonia) - Render Markdown in Avalonia.
- [MuPDFCore](https://github.com/arklumpus/MuPDFCore) - Multi-platform .NET bindings for [MuPDF](https://mupdf.com/).
- [PdfLibCore](https://github.com/jbaarssen/PdfLibCore) - A fast PDF editing and reading library for modern .NET Core applications.
- [Print to PDF](https://github.com/Oaz/AvaloniaUI.PrintToPDF) - An experimental library for creating PDFs from Avalonia UI visuals.

#### Media Players

- [Avalonia Accelerate](https://avaloniaui.net/accelerate#mediaplayer) - A premium Media Player control, developed by the team behind Avalonia.
- [AvaloniaGif](https://github.com/AvaloniaUI/Avalonia.GIF) - Purely C# GIF decoder and animation library.
- [FFME.Avalonia](https://github.com/WangsYi/ffme.avalonia) - MediaElement based on FFMpeg.
- [LibVLCSharp.Avalonia](https://code.videolan.org/videolan/LibVLCSharp) - A cross-platform LibVLC Media Player SDK for .NET with Avalonia integration.
- [MarcusW.VncClient](https://github.com/MarcusWichelmann/MarcusW.VncClient) - A high-performance, cross-platform VNC client control with Avalonia support.
- [MediaPlayerUI](https://github.com/mysteryx93/MediaPlayerUI.NET/) - Re-usable media player UI.

#### UI Libraries

- [Actipro Avalonia UI Controls](https://github.com/Actipro/Avalonia-Controls) - Free UI controls and beautiful themes, along with a Pro option for advanced controls.
- [Aura.UI](https://github.com/PieroCastillo/Aura.UI) - A Library with a lot of Controls for AvaloniaUI.
- [AtomUI](https://github.com/chinware/AtomUI) - AtomUI is an implementation of Ant Design based on Avalonia/.NET technology, and is committed to bringing Ant Design's excellent and efficient design language and experience to the Avalonia/.NET cross-platform desktop software development field.
- [AvaloniaAutoGrid](https://github.com/AvaloniaUI/AvaloniaAutoGrid) - A flexible, easy to configure replacement for the standard Grid control.
- [AvaloniaCalendarView](https://github.com/eugenenoble2005/avaloniacalendarview) - Editable month view, week view and day view calendar control for Avalonia.
- [AvaloniaColorPicker](https://github.com/arklumpus/AvaloniaColorPicker) - A color picker that supports RGB, HSB, and CIELAB color spaces.
- [AvaloniaControlsToolBar](https://github.com/Tulesha/Avalonia.Controls.ToolBar) - A ToolBar and ToolBarTray controls for Avalonia.
- [AvaloniaEdit](https://github.com/AvaloniaUI/AvaloniaEdit) - This is a port of AvalonEdit for Avalonia.
- [AvaloniaFixedWrapPanel](https://github.com/MikD1/AvaloniaFixedWrapPanel) - Avalonia WrapPanel with fixed number of items per line.
- [AvaloniaGraphControl](https://github.com/Oaz/AvaloniaGraphControl) - A graph layout panel based on [Microsoft Automatic Graph Layout](https://github.com/microsoft/automatic-graph-layout).
- [AvaloniaHex](https://github.com/Washi1337/AvaloniaHex) - A hex editor control for Avalonia.
- [AvaloniaNavigationBar](https://github.com/lukewire129/navigationbar-avaloniaui) - Custom BottomNavigationBar Sample.
- [AvaloniaNavigationPage](https://github.com/lukewire129/AvaloniaNavigationPage) - Page Transition Mechanism.
- [AvaloniaProgressRing](https://github.com/Deadpikle/AvaloniaProgressRing) - A simple progress ring control based on [ModernWpf's progress ring](https://github.com/Kinnara/ModernWpf/wiki/ProgressRing).
- [AvaloniaRibbon](https://github.com/Splitwirez/AvaloniaRibbon) - Ribbon for Avalonia.
- [AvaloniaSpacedGrid](https://github.com/Nickelony/SpacedGrid-Avalonia) - An extension of AvaloniaUI's Grid class with added RowSpacing and ColumnSpacing properties.
- [Avalonia.PropertyGrid](https://github.com/bodong1987/Avalonia.PropertyGrid) - A property editing control similar to DevExpress.PropertyGridControl.
- [CalendarControl](https://github.com/satial-interfaces/CalendarControl) - A calendar control (week view) for Avalonia.
- [DialogHost.Avalonia](https://github.com/AvaloniaUtils/DialogHost.Avalonia) - Managed asynchronous overlay dialogs implementation.
- [Dock](https://github.com/wieslawsoltes/Dock) - A docking layout system.
- [Egorozh.ColorPicker](https://github.com/egorozh/Egorozh.ColorPicker) - A color picker with RGB and HSB support.
- [EremexControls.NET](https://github.com/Eremex/controls-demo) - Commercial UI controls for the cross-platform Avalonia UI framework to help you deliver cutting-edge applications with enhanced UX.
- [ExtendedToolkit](https://github.com/mameolan/Avalonia.ExtendedToolkit) - Extended Controls for Avalonia UI.
- [FluentAvalonia](https://github.com/amwx/FluentAvalonia) - Fluent Design and WinUi Controls.
- [GMap.NET](https://github.com/judero01col/GMap.NET) - GMap.NET Allows the use of routing, geocoding, directions and maps from Google, Yahoo!, Bing, OpenStreetMap, ArcGIS, Pergo, SigPac, Yendux, Mapy.cz, Maps.lt, iKarte.lv, NearMap, HereMap, CloudMade, WikiMapia, MapQuest, and many more.
- [HyperText](https://github.com/AvaloniaUtils/HyperText.Avalonia) - Control for visualizing and using hypertext.
- [JamSoft.AvaloniaUI.Dialogs](https://github.com/jamsoft/JamSoft.AvaloniaUI.Dialogs) - An MVVM dialog service. Allows custom views, file dialogs, and includes a complete multistep Wizard Control.
- [JamSoft.AvaloniaUI.Lcd](https://www.nuget.org/packages/JamSoft.AvaloniaUI.Lcd#readme-body-tab) - A highly configurable animated segmented LCD control.
- [MessageBox.Avalonia](https://github.com/AvaloniaCommunity/MessageBox.Avalonia) - Message Box UI for Avalonia UI.
- [Movere](https://github.com/jp2masa/Movere) - Movere is an implementation of managed dialogs for Avalonia.
- [MvvmNavigation](https://github.com/Egor92/MvvmNavigation) - MVVM friendly library for easy navigation management in Avalonia applications.
- [NodifyM.Avalonia](https://github.com/MakesYT/NodifyM.Avalonia) - A collection of controls for node based editors designed for MVVM.
- [NodifyAvalonia](https://github.com/BAndysc/nodify-avalonia) - Highly performant and modular controls for node-based editors designed for data-binding and MVVM. 1-1 port of WPF's version.
- [Notification.Avalonia](https://github.com/AvaloniaCommunity/Notification.Avalonia) - Control for show different information in LINQ style.
- [NP.Avalonia.Visuals](https://github.com/npolyak/NP.Avalonia.Visuals) - Additional visual controls by npolyak.
- [Paginator.Avalonia](https://github.com/AvaloniaUtils/Paginator.Avalonia) - A paginator control.
- [PanAndZoom](https://github.com/wieslawsoltes/PanAndZoom) - Pan and zoom control for WPF and Avalonia.
- [RangeSlider](https://github.com/DmitryNizhebovsky/Avalonia.RangeSlider) - RangeSlider control.
- [Ripple Effect](https://github.com/Roflyanochka/AvaloniaRipple) - Sample of ripple effect.
- [Tabalonia](https://github.com/egorozh/Tabalonia) - Tab Control with drag-able tabs.
- [Ursa.Avalonia](https://github.com/irihitech/Ursa.Avalonia) - Ursa is a UI library for building cross-platform UIs with Avalonia UI.
- [UVtools.AvaloniaControls](https://github.com/sn4k3/UVtools/tree/master/UVtools.AvaloniaControls) - Fast and configurable AdvancedImageBox with image modes, pan & zoom, select regions, pixel grid, and cursor images.
- [Xamarin.Forms.Platform.Avalonia](https://github.com/zhongzf/Xamarin.Forms.Platform.Avalonia) - Xamarin Forms platform implemented with Avalonia (A multi-platform .NET UI framework).

### Games and Game engines

- [AvaloniaTetris](https://github.com/IvanJosipovic/AvaloniaTetris) - A Tetris game written with Avalonia.
- [BattleCity](https://github.com/kekekeks/Avalonia.BattleCity) - 2D game stub rendered completely by AvaloniaUI.
- [Estragonia](https://github.com/MrJul/Estragonia) - Integration of Avalonia into the Godot game engine.
- [Macabre2D](https://github.com/Macabresoft/Macabre2D/) - A game engine built on MonoGame.
- [MonoGame](https://github.com/AvaloniaInside/AvaloniaInside.MonoGame) - Integration of MonoGame for Avalonia.
- [PokemonBattleEngine](https://github.com/Kermalis/PokemonBattleEngine) - A C# library that can emulate Pokémon battles.

### Web Browsers

- [Avalonia Accelerate](https://avaloniaui.net/accelerate#webview) - A premium Web View control, developed by the team behind Avalonia.
- [CefGlue](https://github.com/OutSystems/CefGlue) - .NET/Mono binding for The Chromium Embedded Framework (CEF).
- [DotNetBrowser](https://teamdev.com/dotnetbrowser/) - Premium Chromium web browser control for Windows, Linux, and macOS.
- [OutSystems WebView](https://github.com/OutSystems/WebView) - Fully-featured Avalonia WebView Control.

## Videos

- [libdrm and Multi Touch](https://www.youtube.com/watch?v=t8Ww17iPdqs) - Avalonia libdrm/egl/libinput backend progress.
- [Nikita Tsukanov - Framebuffer](https://www.youtube.com/watch?v=NkTPfBfDmtA) - AvaloniaUI running without X server on top of /dev/fb0 and libevdev2.
- [Nikita Tsukanov - XAML-oriented](https://www.youtube.com/watch?v=DLHhZJkSqWk) - AvaloniaUI - cross-platform XAML-oriented .NET UI framework.
- [VNC Server](https://www.youtube.com/watch?v=HAyHIvSzweM) - Avalonia acting as a VNC server.
- [World of Zero - Hello World](https://www.youtube.com/watch?v=rho26Ik30D4) - A cross-platform .NET UI Framework - Hello World in Avalonia UI.

## Articles

- [Artyom Gorchakov in The Startup - A Cross-Platform GUI Theme for Desktop .NET Core Applications](https://medium.com/swlh/cross-platform-gui-for-dotnet-applications-bbd284709600) - Getting started with building awesome cross-platform user interfaces with Avalonia framework and a modern UI theme.
- [Hanselman - Cross-platform .NET UI Framework](https://www.hanselman.com/blog/what-would-a-crossplatform-net-ui-framework-look-like-exploring-avalonia) - What would a cross-platform .NET UI Framework look like? Exploring Avalonia.
- [idiwork - Cross-platform apps with XAML](https://www.idiwork.com/avalonia-a-big-candidate-to-create-crossplatform-apps-with-xaml/) - Avalonia, a big candidate to create cross-platform apps with XAML.

## Podcasts

- [HanselMinutes - E684](https://www.hanselminutes.com/684/avalonia-is-a-cross-platform-xaml-framework-for-net-framework-net-core-and-mono-with-steve) - Steven Kirk is on HanselMinutes to talk about Avalonia UI.

## Presentations slides

## Tooling

- [Avalonia Accelerate - Dev Tools](https://avaloniaui.net/accelerate#devtools) - Enhanced Developer Tools with advanced inspection, diagnostics, and debugging features.
- [Avalonia Material Icon Pack](https://github.com/aboimpinto/MaterialDesign.Avalonia) - All Material Icons Pack that can be found in https://fonts.google.com/icons (net5.0 only).
- [Avalonia Toolkit](https://github.com/rabbitism/AvaloniaToolkit) - Visual Studio Extension to generate boilerplate Avalonia related code.
- [Avant Garde](https://github.com/kuiperzone/AvantGarde) - Standalone cross-platform XAML previewer for the C# Avalonia Framework.
- [Citrus.Avalonia](https://github.com/AvaloniaUI/Citrus.Avalonia) - Modern styles for Avalonia controls.
- [dotnet-properties](https://github.com/jp2masa/dotnet-properties) - .NET Core CLI extension that allows editing project properties using a cross-platform UI.
- [HotAvalonia](https://github.com/Kir-Antipov/HotAvalonia) - Supercharge your Avalonia development experience with hot reload capabilities.
- [IconPacks](https://github.com/ahopper/Avalonia.IconPacks) - Import of more than 21,000 vector icons from the Visual Studio image library, VSCode Icons, and MahApps.Metro.IconPacks.
- [IconPacks Testbed](https://github.com/punker76/MahApps.Avalonia.IconPacks.Testbed) - Testbed for MahApps.Avalonia.IconPacks.
- [Live.Avalonia](https://github.com/worldbeater/Live.Avalonia) - Live reloading tool for developing Avalonia applications.
- [PupNet Deploy](https://github.com/kuiperzone/PupNet-Deploy) - Cross-platform deployment utility which publishes your Avalonia application and packages it as a ready-to-ship installation file.
- [Rider Plugin for Avalonia](https://github.com/ForNeVeR/AvaloniaRider) - JetBrains Rider plugin for Avalonia development.
- [Svg.Skia](https://github.com/wieslawsoltes/Svg.Skia) - An SVG rendering library with an example of Avalonia.
- [ThemeEditor](https://github.com/wieslawsoltes/ThemeEditor) - ThemeEditor is an Avalonia UI Framework theme editor.
- [ThemeManager](https://github.com/wieslawsoltes/Avalonia.ThemeManager) - Theme manager for Avalonia applications.

## Books

## E-Books

- [AvaloniaUI - Applicazioni Desktop Multipiattaform in C#](http://robertobandiera.altervista.org/LibroAvaloniaUI/) - AvaloniaUI book by [Roberto Bandiera](http://robertobandiera.altervista.org/) (italian language).

## Courses

## Community

- [Bug Reports](https://github.com/AvaloniaUI/Avalonia/issues) - GitHub Issues page.
- [Gitter Chat](https://gitter.im/AvaloniaUI/Avalonia) - Gitter Chat.
- [Stack Overflow](https://stackoverflow.com/questions/tagged/avaloniaui) - Ask questions on Stack Overflow with the `avaloniaui` tag.

## Other Languages

- [entwickler - eine Cross-Plattform-Lösung](https://entwickler.de/online/windowsdeveloper/xaml-cross-plattform-loesung-579812969.html) - XAML-Tipp: Avalonia – eine Cross-Plattform-Lösung für XAML.
- [LauZyHou - sbid-ava](https://github.com/LauZyHou/sbid-ava) - 内生安全建模工具，基于.NET Core 3.0 的 Avalonia 跨平台桌面应用。
- [Nikita Tsukanov - CLRium](https://www.youtube.com/watch?v=6uq1-ii26Es) - CLRium #3: Кросс-платформенная разработка с использованием AvaloniaUI.
- [Nikita Tsukanov - DotNext](https://www.youtube.com/watch?v=8qzqweimcFs) - Никита Цуканов — AvaloniaUI — первый кроссплатформенный XAML UI-фреймворк с поддержкой .NET Core.
